import { editMediaFolder } from "@/services/launchAdq/material"
import { Form, message, Modal, Select } from "antd"
import React, { useState } from "react"
import { useModel } from "umi"


interface Props {
    catalogueData: any[]
    isAll: boolean
    visible?: boolean
    onChange?: () => void
    onClose?: () => void
}
/**
 * 移动至
 * @returns 
 */
const MoveTo: React.FC<Props> = ({ isAll, visible, onClose, catalogueData = [] }) => {

    /*****************************/
    const { state, list } = useModel(isAll ? 'useLaunchAdq.useBdMedia' : 'useLaunchAdq.useBdMediaPup')
    const { selectFile, mediaType, belongUser } = state
    const [form] = Form.useForm();
    const [loading, setLoading] = useState<boolean>(false)
    /*****************************/

    const handleOk = () => {
        form.validateFields().then(values => {
            if (selectFile && selectFile?.length > 0) {
                let hide = message.loading('移动至。。。', 0)
                setLoading(true)
                let ajax = selectFile.map(id => editMediaFolder({ sysMediaId: id, folderId: values.folderId, mediaType: mediaType as any }))
                Promise.all(ajax).then(res => {
                    console.log('移动至。。。', res);
                    if (res[0]?.data) {
                        list.refresh()
                        setLoading(false)
                        hide()
                        message.success('移动成功')
                        onClose?.()
                    }
                })
            }
        })
    }

    return <Modal
        title="移动至"
        visible={visible}
        onCancel={() => onClose?.()}
        onOk={handleOk}
        confirmLoading={loading}
    >
        <Form
            form={form}
            labelCol={{ span: 4 }}
            className='ad_form_style'
            colon={false}
            initialValues={{}}
        >
            <Form.Item label={<strong>文件夹</strong>} name='folderId' rules={[{ required: true, message: '请选择文件夹' }]}>
                <Select style={{ width: 380 }} placeholder='请选择'>
                    {[{ title: belongUser == 1 ? '个人本地' : '公共本地', id: 0 }, ...catalogueData]?.map((item) => <Select.Option value={item.id} key={item.id}>{item.title}</Select.Option>)}
                </Select>
            </Form.Item>
        </Form>
    </Modal>
}


export default React.memo(MoveTo)